@@ -28,9 +28,14 @@ def get_qlbond(bond_info: FixedRateBond, setting: BondSetting,
                 calendar):
     ql_period = ql.Period(ql_freq_tenor[setting.frequency])
     day_count = ql_day_count[setting.day_count]
-    schedule = ql.MakeSchedule(datestr_to_qldate(bond_info.issue_date), 
-                                datestr_to_qldate(bond_info.maturity), 
-                                ql_period)
+    schedule = ql.Schedule(datestr_to_qldate(bond_info.issue_date), 
+                            datestr_to_qldate(bond_info.maturity), 
+                            ql_period, 
+                            calendar, 
+                            ql_business_day[setting.business_day],
+                            ql_business_day[setting.terminate_business_day],
+                            ql_date_generation[setting.date_gen],
+                            setting.is_eom)
 
     interest = ql.FixedRateLeg(schedule, 
                                 day_count, 
@@ -89,6 +94,7 @@ def fixbond_ytm(clean_price: float,
                 daycount: DayCount,
                 frequency: Frequency,
                 thebond: ql.QuantLib.Bond):
+    
     day_count = ql_day_count[daycount]
     freq = ql_frequency[frequency]
     ytm = thebond.bondYield(clean_price, 
